from setuptools import setup

setup(name='bn_distributions',
      version='0.1',
      description='Gaussian, General and Binomial distributions',
      packages=['distributions'],
      author = 'Gazal Gupta',
      author_email = 'gazalgupta30@gmail.com',
      zip_safe=False)
